@@ -20,4 +20,11 @@ def bootstrap():
     for json_mix in json_mixes
   ]
   
-  return mixes
+  tracks = {}
+  for mix in mixes:
+    for track in mix.tracklist:
+      if track.id is None:
+        continue
+      tracks[track.id] = track
+  
+  return mixes, tracks
