@@ -48,5 +48,5 @@ class Mix(Audio):
           continue
         track.download()
       except Exception as e:
-        logging.error(f'Failed to download track: https://www.youtube.com/watch?v={track["id"]}')
+        logging.error(f'Failed to download mix: https://www.youtube.com/watch?v={track.id}')
         traceback.print_exc()
